@@ -3,7 +3,7 @@ package BorderStyles::Test;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-06-11'; # DATE
 our $DIST = 'BorderStyles-Test'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 1;
 # ABSTRACT: A collection of border styles, mainly for testing
@@ -20,7 +20,7 @@ BorderStyles::Test - A collection of border styles, mainly for testing
 
 =head1 VERSION
 
-This document describes version 0.001 of BorderStyles::Test (from Perl distribution BorderStyles-Test), released on 2020-06-11.
+This document describes version 0.002 of BorderStyles::Test (from Perl distribution BorderStyles-Test), released on 2020-06-11.
 
 =head1 HOMEPAGE
 
@@ -38,6 +38,14 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<BorderStyle> - specification
+
+L<App::BorderStyleUtils> - CLIs
+
+L<Text::Table::TinyBorderStyle>, L<Text::ANSITable> - some table renderers that can use border styles
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
